Learn R Programming

drclust (version 0.1.1)

silhouette: Silhouette

Description

Computes and plots the silhouette of a partition

Usage

silhouette(data, drclust_out)

Value

cl.silhouette

Silhouette index for the given partition, for each object (matrix).

fe.silhouette

Factoextra silhouette graphical object

Arguments

data

Units x variables data matrix.

drclust_out

Out of either doublekm, redkm, factkm or dpcakm.

Author

Ionel Prunila, Maurizio Vichi

References

Rousseeuw P. J. (1987) "Silhouettes: a Graphical Aid to the Interpretation and Validation of Cluster Analysis" <doi:10.1016/0377-0427(87)90125-7>

Maechler M. et al. (2023) "cluster: Cluster Analysis Basics and Extensions" <https://CRAN.R-project.org/package=cluster>

Kassambara A. (2022) "factoextra: Extract and Visualize the Results of Multivariate Data Analyses" <https://cran.r-project.org/web/packages/factoextra/index.html>

Examples

Run this code
# Iris data 
# Loading the numeric variables of iris data
iris <- as.matrix(iris[,-5]) 

#standardizing the data
iris <- scale(iris)

#applying a clustering algorithm
drclust_out <- dpcakm(iris, 20, 3)

#silhouette based on the data and the output of the clustering algorithm
d <- silhouette(iris, drclust_out)

Run the code above in your browser using DataLab